/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/trunk/backends/platform/iphone/iphone_video.h $
 * $Id: iphone_video.h 40867 2009-05-24 15:17:42Z lordhoto $
 *
 */

#ifndef _IPHONE_VIDEO__H
#define _IPHONE_VIDEO__H

#import <engines/engine.h>
#import <engines/igob/gob.h>
#import <engines/igob/goblin.h>
#import <engines/igob/script.h>
#import <engines/igob/hotspots.h>
#import <engines/igob/game.h>

#import <vector>
#import <UIKit/UIKit.h>
#import <Foundation/Foundation.h>
#import <AVFoundation/AVFoundation.h>
#import <QuartzCore/QuartzCore.h>

#import <OpenGLES/EAGL.h>
#import <OpenGLES/ES1/gl.h>
#import <OpenGLES/ES1/glext.h>

@interface iPhoneView : UIView <UIAlertViewDelegate>
{
	//VIEW PARAMS
	void* _screenSurface;
	NSMutableArray* _events;
	CALayer* _screenLayer;

	//OPENGL PARAMS
	EAGLContext* _context;
	GLuint _viewRenderbuffer;
	GLuint _viewFramebuffer;
	GLint _backingWidth;
	GLint _backingHeight;
	GLint _visibleWidth;
	GLint _visibleHeight;
	GLuint _screenTexture;
	
	//DEVICE PARAM
	UIDeviceOrientation _screenOrientation;
	
	//VIDEO PARAMS
	int _fullWidth;
	int _fullHeight;
	int _widthOffset;
	int _heightOffset;
	NSLock* _lock;

	////////////////////////////////////
	// GAME PARAMS
	//----------------------------------
	
	//OUTLETS
	IBOutlet UIButton* skipButton;
	IBOutlet UIButton* choiceButton;
	IBOutlet UIButton* hintButton;
	IBOutlet UIButton* menuButton;
	IBOutlet UIImageView* barreInventaire;
	IBOutlet UIImageView* tutoBar;
	
	//DISPLAY
	bool hotspotDisplayed[20];
	bool hotspotUsed[20];
	bool iconsDisplayed;
	bool alphaDisplayed[20];
	bool alphaButtonsDisplayed;
	
	UIImageView* hotspotImgView[20];		
	UIImage*     hotspotImg;
	UIImageView* rondV;
	UIImageView* cursorGobliiin;
	
	//SOUND
	AVAudioPlayer* popupSound;

	//ACTIONS
	UIButton* useIcon;
	UIButton* pickIcon;
	UIButton* stepIcon;
	UIButton* cancelIcon;
	UIButton* tutoIcon;
	
	int   mEtatAction;
	float stepPosX;
	float stepPosY;
	bool  bStepIconOn;
	bool  buttonFade;
	
	//DIVERS
	NSInteger    date_second;
	UIAlertView* alert;
	
	//TUTO
	bool bAnimatingButtons;
	bool next;
	int  etatTuto;
	UIImageView* pointerButton;
	UIImageView* tutoTitleV;
	UITextView*  msgBegin;
	CGRect       pointerButtonRect;

	//GOB
	Gob::GobEngine* gg;
	int  xPosCur, yPosCur;
	bool reset;
	NSDate* debD;
	NSDate* endD;
	int  tempoMusicSound;
	bool bCancelAction;
	
	//SAVE
	NSString *docsDirectory;
    NSString *path;
    NSString *path_sound;
    NSString *path_control;	
	
	//game over screen
	UIImageView* gameoverV;
	
	//splash loading
	IBOutlet UIImageView* loadingV;
	IBOutlet UIActivityIndicatorView * activityIndicator;
	bool bLoadingImage;

	//-----------------------------------
	/////////////////////////////////////
}

//CLASS
- (id)   initWithFrame:(struct CGRect)frame;
- (void) awakeFromNib;
- (void) applicationSuspend;
- (void*)getSurface; 
- (void) updateSurface; 
- (void) initSurface;
- (id)   getEvent;
- (void) addEvent:(NSDictionary*)event; 
- (void) deviceOrientationChanged:(UIDeviceOrientation)orientation; 
- (void) touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event;
- (void) touchesMoved:(NSSet *)touches withEvent:(UIEvent *)event;
- (void) touchesEnded:(NSSet *)touches withEvent:(UIEvent *)event;
- (void) touchesCancelled:(NSSet *)touches withEvent:(UIEvent *)event;

//ACTIONS
- (IBAction) useIconClicked:(id)sender;
- (IBAction) pickIconClicked:(id)sender;
- (IBAction) stepIconClicked:(id)sender;
- (IBAction) cancelIconClicked:(id)sender;
- (IBAction) choiceButtonClicked:(id)sender;
- (IBAction) nextTuto:(id)sender;

//TUTO
- (void) tutoStepOne;
- (void) tutoStepTwo;
- (void) tutoStepThree;
- (void) tutoStepFour;
- (void) tutoStepFive;
- (void) tutoStepSix;
- (void) tutoStepSeven;
- (void) tutoStepEight;
- (void) endTuto;

//METHODS
- (void) writeSettingsLvL;
- (void) writeSettingsSound;
- (void) clearIcons;
- (void) iconsPositionCompute:(float)xPos coordY:(float)yPos;
- (int)  hotspotDistance:(CGPoint)point;
- (void) hotspotDisplayCompute:(CGPoint)point;
- (void) resetAction:(float)xTouch coordY:(float)yTouch;
- (void) pickObject:(float)xTouch coordY:(float)yTouch;
- (void) clearButtons;
- (void) cursorCurrentGobliiin:(int)xxx coordY:(int)yyy;

//accessors
bool getLocalMouseCoords(CGPoint *point);

@end

#endif /* _IPHONE_VIDEO__H */
